#!/usr/bin/env python
# -*- encoding: utf-8 -*-

# Copyright 2020, Nigel Small
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from pansi import ansi


def test_ansi_reset():
    assert "{reset}".format(**ansi) == "\x1b[0m"


def test_ansi_reset_alias():
    assert "{_}".format(**ansi) == "\x1b[0m"


def test_ansi_black():
    assert "{black}".format(**ansi) == "\x1b[30m"


def test_ansi_red():
    assert "{red}".format(**ansi) == "\x1b[31m"


def test_ansi_green():
    assert "{green}".format(**ansi) == "\x1b[32m"


def test_ansi_yellow():
    assert "{yellow}".format(**ansi) == "\x1b[33m"


def test_ansi_blue():
    assert "{blue}".format(**ansi) == "\x1b[34m"


def test_ansi_magenta():
    assert "{magenta}".format(**ansi) == "\x1b[35m"


def test_ansi_cyan():
    assert "{cyan}".format(**ansi) == "\x1b[36m"


def test_ansi_white():
    assert "{white}".format(**ansi) == "\x1b[37m"


def test_ansi_bright_black():
    assert "{BLACK}".format(**ansi) == "\x1b[90m"


def test_ansi_bright_red():
    assert "{RED}".format(**ansi) == "\x1b[91m"


def test_ansi_bright_green():
    assert "{GREEN}".format(**ansi) == "\x1b[92m"


def test_ansi_bright_yellow():
    assert "{YELLOW}".format(**ansi) == "\x1b[93m"


def test_ansi_bright_blue():
    assert "{BLUE}".format(**ansi) == "\x1b[94m"


def test_ansi_bright_magenta():
    assert "{MAGENTA}".format(**ansi) == "\x1b[95m"


def test_ansi_bright_cyan():
    assert "{CYAN}".format(**ansi) == "\x1b[96m"


def test_ansi_bright_white():
    assert "{WHITE}".format(**ansi) == "\x1b[97m"


def test_ansi_rgb_3():
    assert "{rgb[#F90]}".format(**ansi) == "\x1b[38;2;255;153;0m"


def test_ansi_rgb_6():
    assert "{rgb[#FF8000]}".format(**ansi) == "\x1b[38;2;255;128;0m"


def test_ansi_rgb_bad_values():
    try:
        _ = "{rgb[#XXYYZZ]}".format(**ansi)
    except ValueError:
        assert True
    else:
        assert False


def test_ansi_rgb_bad_format():
    try:
        _ = "{rgb[#31415926535]}".format(**ansi)
    except ValueError:
        assert True
    else:
        assert False



#!/usr/bin/env python
# -*- encoding: utf-8 -*-

# Copyright 2020, Nigel Small
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from io import StringIO

from pansi import ansi
from pansi.console import Console


def test_console_write():
    captured = StringIO()
    con = Console(__name__, out=captured)
    con.write("hello, world")
    assert captured.getvalue() == "hello, world\n"


def test_console_debug_output():
    captured = StringIO()
    con = Console(__name__, out=captured, verbosity=1)
    con.debug("hello, world")
    assert captured.getvalue() == "{cyan}hello, world{_}\n".format(**ansi)


def test_console_info_output():
    captured = StringIO()
    con = Console(__name__, out=captured)
    con.info("hello, world")
    assert captured.getvalue() == "hello, world\n"


def test_console_warning_output():
    captured = StringIO()
    con = Console(__name__, out=captured, verbosity=1)
    con.warning("hello, world")
    assert captured.getvalue() == "{yellow}hello, world{_}\n".format(**ansi)


def test_console_error_output():
    captured = StringIO()
    con = Console(__name__, out=captured, verbosity=1)
    con.error("hello, world")
    assert captured.getvalue() == "{red}hello, world{_}\n".format(**ansi)


def test_console_critical_output():
    captured = StringIO()
    con = Console(__name__, out=captured, verbosity=1)
    con.critical("hello, world")
    assert captured.getvalue() == "{RED}hello, world{_}\n".format(**ansi)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-

# Copyright 2020, Nigel Small
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from os.path import dirname, join as path_join
from setuptools import setup, find_packages


from pansi import (
    __author__,
    __email__,
    __license__,
    __package__,
    __version__,
)


source_url = "https://github.com/technige/pansi"


with open(path_join(dirname(__file__), "README.rst")) as f:
    README = f.read().replace(".. image :: art/",
                              ".. image :: {}/raw/master/art/".format(source_url))


packages = find_packages(exclude=("demo", "docs", "test"))
package_metadata = {
    "name": __package__,
    "version": __version__,
    "description": "ANSI escape code library for Python",
    "long_description": README,
    "author": __author__,
    "author_email": __email__,
    "url": source_url,
    "project_urls": {
        "Bug Tracker": "{}/issues".format(source_url),
        "Source Code": source_url,
    },
    "entry_points": {
        "console_scripts": [
        ],
    },
    "packages": packages,
    "py_modules": [
    ],
    "install_requires": [
        "six",
    ],
    "extras_require": {
    },
    "license": __license__,
    "classifiers": [
        "Development Status :: 1 - Planning",
        "Environment :: Console",
        "Environment :: Console :: Curses",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Console Fonts",
        "Topic :: System :: Shells",
        "Topic :: Terminals",
        "Topic :: Terminals :: Terminal Emulators/X Terminals",
        "Topic :: Text Processing",
        "Topic :: Text Processing :: Markup",
        "Topic :: Utilities",
    ],
}

setup(**package_metadata)
